<!DOCTYPE TS><TS>
<context>
    <name>AddRecording</name>
    <message>
        <source>Schedule a:</source>
        <translation>Agende :</translation>
    </message>
    <message>
        <source>&amp;Recording</source>
        <translation>&amp;Gravação</translation>
    </message>
    <message>
        <source>&amp;Playout</source>
        <translation>&amp;Execução</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Download</translation>
    </message>
    <message>
        <source>&amp;Upload</source>
        <translation>&amp;Upload</translation>
    </message>
    <message>
        <source>&amp;Macro Cart</source>
        <translation>&amp;Cartão Macro</translation>
    </message>
    <message>
        <source>&amp;Switch Event</source>
        <translation>&amp;Evento de Switch</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>CatchListView</name>
    <message>
        <source>Edit Cue Markers</source>
        <translation>Editar Marcadores</translation>
    </message>
</context>
<context>
    <name>DeckMon</name>
    <message>
        <source>MON</source>
        <translation>MON</translation>
    </message>
    <message>
        <source>ABORT</source>
        <translation>ABORTAR</translation>
    </message>
    <message>
        <source>OFFLINE</source>
        <translation>DESCONECT</translation>
    </message>
    <message>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <source>IDLE</source>
        <translation>CONECTADO</translation>
    </message>
    <message>
        <source>READY</source>
        <translation>PRONTO</translation>
    </message>
    <message>
        <source>WAITING</source>
        <translation>ESPERANDO</translation>
    </message>
    <message>
        <source>RECORDING</source>
        <translation>GRAVANDO</translation>
    </message>
    <message>
        <source>PLAYING</source>
        <translation>EXECUTANDO</translation>
    </message>
    <message>
        <source>[multiple events]</source>
        <translation>[múltiplos eventos]</translation>
    </message>
    <message>
        <source>[unknown cut]</source>
        <translation>[conteúdo desconhecido]</translation>
    </message>
    <message>
        <source>[no description]</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>EditCartEvent</name>
    <message>
        <source>Edit Cart Event</source>
        <translation>Editar Evento Macro</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Ativo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Local:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Início:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Cart Number:</source>
        <translation>Cartão:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Dias Ativos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda-Feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-Feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-Feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-Feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Somente Uma Vez</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Salvar como
Novo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Duplicar Evento</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Um Evento com estes parâmetros já existe!</translation>
    </message>
    <message>
        <source>Invalid Cart</source>
        <translation>Cartão Inválido</translation>
    </message>
    <message>
        <source>That cart doesn&apos;t exist!</source>
        <translation>O Cartão não existe!</translation>
    </message>
</context>
<context>
    <name>EditDownload</name>
    <message>
        <source>Edit Download</source>
        <translation>Editar Download</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Ativo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Local:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Início:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>Url:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canais:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Auto-Corte</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Dias Ativos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda-Feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-Feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-Feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-Feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Uma Vez</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation>Offset do Evento:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dias</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Salvar como
Novo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Duplicar Evento</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Um Evento com estes parâmetros já existe!</translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>URL Inválida</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>A URL é Inválida!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>Protocolo URL sem suporte!</translation>
    </message>
    <message>
        <source>Update Library Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditPlayout</name>
    <message>
        <source>Edit Playout</source>
        <translation>Editar Execução</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Ativo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Local:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Início:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Dias Ativos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda-Feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-Feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-Feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-Feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Somente Uma Vez</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Salvar como
Novo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Duplicar Evento</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Um Evento com estes parâmetros já existe!</translation>
    </message>
</context>
<context>
    <name>EditRecording</name>
    <message>
        <source>Edit Recording</source>
        <translation>Editar Gravação </translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Ativo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Local:</translation>
    </message>
    <message>
        <source>Start Parameters</source>
        <translation>Parâmetros de Início</translation>
    </message>
    <message>
        <source>Use Hard Time</source>
        <translation>Usar Hora Certa</translation>
    </message>
    <message>
        <source>Record Start Time:</source>
        <translation>Início da Gravação:</translation>
    </message>
    <message>
        <source>Use GPI</source>
        <translation>Usar GPI</translation>
    </message>
    <message>
        <source>Window Start Time:</source>
        <translation>Início - Intervalo:</translation>
    </message>
    <message>
        <source>GPI Matrix:</source>
        <translation>GPI Matrix:</translation>
    </message>
    <message>
        <source>GPI Line:</source>
        <translation>Linha GPI:</translation>
    </message>
    <message>
        <source>Start Delay:</source>
        <translation>Atraso de Início:</translation>
    </message>
    <message>
        <source>Allow Multiple Recordings within this Window</source>
        <translation>Permitir Múltiplas Gravações dentro desta Intervalo</translation>
    </message>
    <message>
        <source>End Parameters</source>
        <translation>Parâmetros de Término</translation>
    </message>
    <message>
        <source>Use Length</source>
        <translation>Usar Duração</translation>
    </message>
    <message>
        <source>Record Length:</source>
        <translation>Duração da Gravação:</translation>
    </message>
    <message>
        <source>Record End Time:</source>
        <translation>Hora de Término da Gravação:</translation>
    </message>
    <message>
        <source>Window End Time:</source>
        <translation>Término - Intervalo:</translation>
    </message>
    <message>
        <source>Max Record Length:</source>
        <translation>Duração Máxima:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Fonte:</translation>
    </message>
    <message>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Canais:</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Auto-Corte</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Dias Ativos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda-Feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-Feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-Feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-Feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta-Feira</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Start Date Offset:</source>
        <translation>Offset - data Início:</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>End Date Offset:</source>
        <translation>Offset - data Término:</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Somente Uma Vez</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Salvar como
Novo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <source>Missing Cut</source>
        <translation>Conteúdo Faltando</translation>
    </message>
    <message>
        <source>You must assign a record cut!</source>
        <translation>Você deve designar um Conteúdo para a gravação!</translation>
    </message>
    <message>
        <source>Record Parameter Error</source>
        <translation>Erro no Parâmetro de Garvação</translation>
    </message>
    <message>
        <source>The start GPI window cannot end before it begins!</source>
        <translation>O Intervalo de início GPI não pode terminar antes de iniciar!</translation>
    </message>
    <message>
        <source>The recording cannot end before it begins!</source>
        <translation>A Gravação não pode terminar antes de começar!</translation>
    </message>
    <message>
        <source>The end GPI window cannot end before it begins!</source>
        <translation>O Intervalo de término GPI não pode terminar antes de iniciar!</translation>
    </message>
    <message>
        <source>The start GPI matrix doesn&apos;t exist!</source>
        <translation>A matrix de início GPI não existe!</translation>
    </message>
    <message>
        <source>The start GPI line doesn&apos;t exist!</source>
        <translation>A Linha de início GPI não existe!</translation>
    </message>
    <message>
        <source>The end GPI matrix doesn&apos;t exist!</source>
        <translation>A matrix de término GPI não existe!</translation>
    </message>
    <message>
        <source>The end GPI line doesn&apos;t exist!</source>
        <translation>A Linha de término GPI não existe!</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Duplicar Evento</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Um Evento com estes parâmetros já existe!</translation>
    </message>
</context>
<context>
    <name>EditSwitchEvent</name>
    <message>
        <source>Edit Switcher Event</source>
        <translation>Editar Evento de Switch</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Ativo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Local:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Início:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Switch Matrix:</source>
        <translation>Matrix de Switch:</translation>
    </message>
    <message>
        <source>Switch Input:</source>
        <translation>Entrada do Switch:</translation>
    </message>
    <message>
        <source>Switch Output:</source>
        <translation>Saída do Switch:</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Dias Ativos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda-Feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-Feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-Feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-Feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Somente Uma Vez</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Salvar como
Novo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>--OFF--</source>
        <translation>--DESLIGADO--</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Duplicar Evento</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Um Evento com estes parâmetros já existe!</translation>
    </message>
</context>
<context>
    <name>EditUpload</name>
    <message>
        <source>Edit Upload</source>
        <translation>Editar Upload</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Ativo</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Local:</translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation>Início:</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[nenhum]</translation>
    </message>
    <message>
        <source>RSS Feed:</source>
        <translation>Feed de RSS:</translation>
    </message>
    <message>
        <source>Source:</source>
        <translation>Fonte:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Selecionar</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descrição:</translation>
    </message>
    <message>
        <source>Url:</source>
        <translation>Url:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Usuário:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Senha:</translation>
    </message>
    <message>
        <source>Export Format:</source>
        <translation>Exportação:</translation>
    </message>
    <message>
        <source>S&amp;et</source>
        <translation>&amp;Ajustar</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizar</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nível:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Active Days</source>
        <translation>Dias Ativos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda-Feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-Feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-Feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-Feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Make OneShot</source>
        <translation>Uma Vez</translation>
    </message>
    <message>
        <source>Event Offset:</source>
        <translation>Offset do Evento:</translation>
    </message>
    <message>
        <source>days</source>
        <translation>dias</translation>
    </message>
    <message>
        <source>&amp;Save As
New</source>
        <translation>&amp;Salvar como
Novo</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Unsupported Format</source>
        <translation>Formato sem suporte</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on this host!</source>
        <translation>O atual formato de exportação selecionado não tem suporte no cliente!</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <source>Duplicate Event</source>
        <translation>Duplicar Evento</translation>
    </message>
    <message>
        <source>An event with these parameters already exists!</source>
        <translation>Um Evento com estes parâmetros já existe!</translation>
    </message>
    <message>
        <source>The currently selected export format is unsupported on host </source>
        <translation>O atual formato de exportação selecionado não tem suporte neste cliente </translation>
    </message>
    <message>
        <source>Invalid URL</source>
        <translation>URL Inválida</translation>
    </message>
    <message>
        <source>The URL is invalid!</source>
        <translation>A URL é Inválida!</translation>
    </message>
    <message>
        <source>Unsupported URL protocol!</source>
        <translation>Protocolo URL sem suporte!</translation>
    </message>
    <message>
        <source>Export Library Metadata</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a username!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation>Relatórios do RDBiblio</translation>
    </message>
    <message>
        <source>Event Report</source>
        <translation>Relatório de Evento</translation>
    </message>
    <message>
        <source>Upload/Download Report</source>
        <translation>Relatório de Download/Upload</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>&amp;Gerar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDCatch - Host:</source>
        <translation type="obsolete">RDCaptura - Cliente:</translation>
    </message>
    <message>
        <source>rdcatch : </source>
        <translation>rdcaptura : </translation>
    </message>
    <message>
        <source>Show Only Active Events</source>
        <translation>Mostrar somente Eventos Ativo</translation>
    </message>
    <message>
        <source>Show Only Today&apos;s Events</source>
        <translation>Mostrar somente Eventos de Hoje</translation>
    </message>
    <message>
        <source>Show DayOfWeek:</source>
        <translation>Mostrar Dia da Semana:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todos</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Dias da Semana</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Domingo</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Segunda-Feira</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Terça-Feira</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Quarta-Feira</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Quinta-Feira</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Sexta</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Sábado</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>DESCRIÇÃO</translation>
    </message>
    <message>
        <source>LOCATION</source>
        <translation>LOCALIZAÇÃO</translation>
    </message>
    <message>
        <source>START</source>
        <translation>INÍCIO</translation>
    </message>
    <message>
        <source>END</source>
        <translation>FIM</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation>FONTE</translation>
    </message>
    <message>
        <source>DESTINATION</source>
        <translation>DESTINO</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation>ORIGEM</translation>
    </message>
    <message>
        <source>ONE SHOT</source>
        <translation>UMA VEZ</translation>
    </message>
    <message>
        <source>TRIM THRESHOLD</source>
        <translation>LIMIAR PARA CORTE</translation>
    </message>
    <message>
        <source>STARTDATE OFFSET</source>
        <translation>COMPENSAR DATA INÍCIO</translation>
    </message>
    <message>
        <source>ENDDATE OFFSET</source>
        <translation>COMPENSAR DATA FIM</translation>
    </message>
    <message>
        <source>FORMAT</source>
        <translation>FORMATO</translation>
    </message>
    <message>
        <source>CHANNELS</source>
        <translation>CANAIS</translation>
    </message>
    <message>
        <source>SAMPLE RATE</source>
        <translation>TAXA DE AMOSTRAGEM</translation>
    </message>
    <message>
        <source>BIT RATE</source>
        <translation>TAXA DE BITS</translation>
    </message>
    <message>
        <source>STATION</source>
        <translation>ESTAÇÃO</translation>
    </message>
    <message>
        <source>DECK</source>
        <translation>DECK</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>CONTEÚDO</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CARTÃO</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPO</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>ESTADO</translation>
    </message>
    <message>
        <source>EXIT CODE</source>
        <translation>CÓDIGO DE SAÍDA</translation>
    </message>
    <message>
        <source>STATE</source>
        <translation>ESTADO</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Deletar</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Rolagem</translation>
    </message>
    <message>
        <source>Reports</source>
        <translation>Relatórios</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>Event Active</source>
        <translation>Evento Ativo</translation>
    </message>
    <message>
        <source>You cannot edit an active event!</source>
        <translation>Você não pode editar um evento ativo!</translation>
    </message>
    <message>
        <source>Are you sure you want to delete event</source>
        <translation>Tem certeza que quer deletar este evento</translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation>Deletar Evento</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Não foi Possível Conectar</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>Não foi Possível Conectar ao Sistema de áudio</translation>
    </message>
    <message>
        <source>Control connection timed out to host</source>
        <translation>Conexão de Controle expirou para o Cliente</translation>
    </message>
    <message>
        <source>Su</source>
        <translation>Dom</translation>
    </message>
    <message>
        <source>Mo</source>
        <translation>Seg</translation>
    </message>
    <message>
        <source>Tu</source>
        <translation>Ter</translation>
    </message>
    <message>
        <source>We</source>
        <translation>Qua</translation>
    </message>
    <message>
        <source>Th</source>
        <translation>Qui</translation>
    </message>
    <message>
        <source>Fr</source>
        <translation>Sex</translation>
    </message>
    <message>
        <source>Sa</source>
        <translation>Sab</translation>
    </message>
    <message>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <source>Hard</source>
        <translation>Certa</translation>
    </message>
    <message>
        <source>Gpi</source>
        <translation>Gpi</translation>
    </message>
    <message>
        <source>Len</source>
        <translation>Dur</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <source>PCM16</source>
        <translation>PCM16</translation>
    </message>
    <message>
        <source>MPEG Layer 1</source>
        <translation>MPEG Layer 1</translation>
    </message>
    <message>
        <source>MPEG Layer 2</source>
        <translation>MPEG Layer 2</translation>
    </message>
    <message>
        <source>MPEG Layer 3</source>
        <translation>MPEG Layer 3</translation>
    </message>
    <message>
        <source>FLAC</source>
        <translation>FLAC</translation>
    </message>
    <message>
        <source>OggVorbis</source>
        <translation>OggVorbis</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cartão</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[nenhum]</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Short Length</source>
        <translation type="obsolete">Duração Curta</translation>
    </message>
    <message>
        <source>Low Level</source>
        <translation type="obsolete">Nível Baixo</translation>
    </message>
    <message>
        <source>High Level</source>
        <translation type="obsolete">Nível Alto</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">Baixando</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation type="obsolete">Subindo</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation type="obsolete">Gravando</translation>
    </message>
    <message>
        <source>Playing</source>
        <translation type="obsolete">Executando</translation>
    </message>
    <message>
        <source>Waiting</source>
        <translation type="obsolete">Esperando</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="obsolete">Erro de Servidor</translation>
    </message>
    <message>
        <source>Internal Error</source>
        <translation type="obsolete">Erro Interno</translation>
    </message>
    <message>
        <source>Interrupted</source>
        <translation type="obsolete">Interrompido</translation>
    </message>
    <message>
        <source>Device Busy</source>
        <translation type="obsolete">Dispositivo Ocupado</translation>
    </message>
    <message>
        <source>No Such Cart/Cut</source>
        <translation type="obsolete">Este Cartão não existe</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PCM24</source>
        <translation type="unfinished">PCM24</translation>
    </message>
    <message>
        <source>Show Event Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Types</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
